import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { G as GetOrderRefundabilityResponse, a as GetOrderRefundabilityResponseNonNullableFields, C as CalculateRefundOptions, b as CalculateRefundResponse, c as CalculateRefundResponseNonNullableFields, R as RefundPaymentsOptions, d as RefundPaymentsResponse, e as RefundPaymentsResponseNonNullableFields, A as AuthorizeChargeWithSavedPaymentMethodOptions, f as AuthorizeChargeWithSavedPaymentMethodResponse, g as AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields, V as VoidAuthorizedPaymentsOptions, h as VoidAuthorizedPaymentsResponse, i as VoidAuthorizedPaymentsResponseNonNullableFields, j as CaptureAuthorizedPaymentsOptions, k as CaptureAuthorizedPaymentsResponse, l as CaptureAuthorizedPaymentsResponseNonNullableFields } from './ecom-v1-order-billing-order-billing.universal-BZCa0Kx1.js';
export { a_ as ActionEvent, r as ActionType, X as AdditionalFeeRefund, K as AdditionalFeeRefundability, _ as AggregatedRefundSummary, a9 as ApplicationError, aC as AuthorizationActionFailureDetails, aB as AuthorizationCapture, o as AuthorizationCaptureStatus, aA as AuthorizationDetails, aD as AuthorizationVoid, p as AuthorizationVoidStatus, aL as AuthorizeChargeWithSavedPaymentMethodRequest, Q as CalculateRefundRequest, Z as CalculateRefundResponseStatusOneOf, a2 as CalculatedAdditionalFeeRefund, a0 as CalculatedLineItemRefund, $ as CalculatedRefundItems, a4 as CalculatedRefundNotAvailableStatus, a1 as CalculatedRefundSummary, a3 as CalculatedShippingRefund, a5 as CalculationError, a6 as CalculationErrorItemOneOf, aP as CaptureAuthorizedPaymentsRequest, E as CreditCardPaymentMethodDetails, aM as DelayedCaptureSettings, a7 as Details, a8 as DetailsKindOneOf, aU as DomainEvent, aV as DomainEventBodyOneOf, aN as Duration, D as DurationUnit, a$ as Empty, aW as EntityCreatedEvent, aZ as EntityDeletedEvent, aY as EntityUpdatedEvent, aJ as ExternalReceiptInfo, ab as FieldViolation, b1 as GenerateReceiptsOptions, aR as GenerateReceiptsRequest, aS as GenerateReceiptsResponse, b0 as GenerateReceiptsResponseNonNullableFields, t as GetOrderRefundabilityRequest, aF as GiftCardPaymentDetails, W as LineItemRefund, at as LineItemRefundSummary, L as LineItemRefundability, F as ManuallyRefundablePaymentStatus, M as ManuallyRefundableReason, aH as MembershipName, aG as MembershipPaymentDetails, s as MembershipPaymentStatus, B as MembershipPaymentSummary, y as MonetaryPaymentSummary, H as NonRefundablePaymentStatus, N as NonRefundableReason, ai as NotificationSideEffects, O as OrderBilling, au as OrderTransactions, av as Payment, aQ as PaymentCapture, v as PaymentInfo, x as PaymentInfoPaymentMethodDetailsOneOf, w as PaymentInfoSummaryOneOf, aK as PaymentNotRefundableDetails, aw as PaymentPaymentDetailsOneOf, ax as PaymentReceiptInfoOneOf, ae as PaymentRefund, P as PaymentRefundability, u as PaymentRefundabilityStatusOneOf, I as PaymentsSummary, z as Price, q as Reason, aT as ReceiptInfo, aj as Refund, am as RefundDetails, an as RefundItem, U as RefundItems, as as RefundItemsBreakdown, ad as RefundPaymentsRequest, af as RefundSideEffects, n as RefundStatus, al as RefundStatusInfo, ak as RefundTransaction, ay as RegularPaymentDetails, az as RegularPaymentDetailsPaymentMethodDetailsOneOf, ag as RestockItem, ah as RestockSideEffects, aX as RestoreInfo, m as RuleType, S as ScheduledAction, Y as ShippingRefund, J as ShippingRefundability, ac as SystemError, T as TransactionStatus, ap as V1AdditionalFeeRefund, ar as V1AggregatedRefundSummary, ao as V1LineItemRefund, aE as V1ScheduledAction, aq as V1ShippingRefund, aa as ValidationError, aO as VoidAuthorizedPaymentsRequest, aI as WixReceiptInfo } from './ecom-v1-order-billing-order-billing.universal-BZCa0Kx1.js';

declare function getOrderRefundability$1(httpClient: HttpClient): GetOrderRefundabilitySignature;
interface GetOrderRefundabilitySignature {
    /**
     * Retrieves refund information about an order's payments, line items, shipping, and additional fees.
     *
     * The following information is returned:
     * - Whether a payment is refundable; previously refunded amounts; possible refund amounts for each payment.
     * - Refundable and previously refunded quantities for each line item, as well as shipping and additional fees.
     * @param - Order ID.
     */
    (orderId: string): Promise<GetOrderRefundabilityResponse & GetOrderRefundabilityResponseNonNullableFields>;
}
declare function calculateRefund$1(httpClient: HttpClient): CalculateRefundSignature;
interface CalculateRefundSignature {
    /**
     * Calculates refund amounts for a given list of an order's line items, shipping, and additional fees.
     * @param - Order ID.
     */
    (orderId: string, options?: CalculateRefundOptions | undefined): Promise<CalculateRefundResponse & CalculateRefundResponseNonNullableFields>;
}
declare function refundPayments$1(httpClient: HttpClient): RefundPaymentsSignature;
interface RefundPaymentsSignature {
    /**
     * Calls relevant payment providers and creates refund transactions for the requested payments.
     *
     * Refunds marked with `paymentRefunds.externalRefund = true` do not call payment providers and
     * only update the order's transactions records.
     * @param - Order ID.
     */
    (orderId: string, options?: RefundPaymentsOptions | undefined): Promise<RefundPaymentsResponse & RefundPaymentsResponseNonNullableFields>;
}
declare function authorizeChargeWithSavedPaymentMethod$1(httpClient: HttpClient): AuthorizeChargeWithSavedPaymentMethodSignature;
interface AuthorizeChargeWithSavedPaymentMethodSignature {
    /**
     * Authorizes a payment using an order's saved payment method.
     *
     * Use the `delayedCaptureSettings` field to specify whether the payment should also be captured/voided immediately or at a later time.
     * Alternatively, the payment can be manually captured or voided using the Capture Authorized Payments or Void Authorized Payments methods.
     * @param - Order ID.
     *
     * The order must have a saved payment method associated.
     * Pass the order ID to the List Transactions For Single Order method and search the response for a payment with `regularPaymentDetails.savedPaymentMethod: true`.
     * If no saved payment exists, the call will fail.
     */
    (orderId: string, options: AuthorizeChargeWithSavedPaymentMethodOptions): Promise<AuthorizeChargeWithSavedPaymentMethodResponse & AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields>;
}
declare function voidAuthorizedPayments$1(httpClient: HttpClient): VoidAuthorizedPaymentsSignature;
interface VoidAuthorizedPaymentsSignature {
    /**
     * Voids an order's authorized payments.
     * @param - Order ID.
     */
    (orderId: string, options: VoidAuthorizedPaymentsOptions): Promise<VoidAuthorizedPaymentsResponse & VoidAuthorizedPaymentsResponseNonNullableFields>;
}
declare function captureAuthorizedPayments$1(httpClient: HttpClient): CaptureAuthorizedPaymentsSignature;
interface CaptureAuthorizedPaymentsSignature {
    /**
     * Captures an order's authorized payments.
     * @param - Order ID.
     */
    (orderId: string, options: CaptureAuthorizedPaymentsOptions): Promise<CaptureAuthorizedPaymentsResponse & CaptureAuthorizedPaymentsResponseNonNullableFields>;
}

declare const getOrderRefundability: MaybeContext<BuildRESTFunction<typeof getOrderRefundability$1> & typeof getOrderRefundability$1>;
declare const calculateRefund: MaybeContext<BuildRESTFunction<typeof calculateRefund$1> & typeof calculateRefund$1>;
declare const refundPayments: MaybeContext<BuildRESTFunction<typeof refundPayments$1> & typeof refundPayments$1>;
declare const authorizeChargeWithSavedPaymentMethod: MaybeContext<BuildRESTFunction<typeof authorizeChargeWithSavedPaymentMethod$1> & typeof authorizeChargeWithSavedPaymentMethod$1>;
declare const voidAuthorizedPayments: MaybeContext<BuildRESTFunction<typeof voidAuthorizedPayments$1> & typeof voidAuthorizedPayments$1>;
declare const captureAuthorizedPayments: MaybeContext<BuildRESTFunction<typeof captureAuthorizedPayments$1> & typeof captureAuthorizedPayments$1>;

export { AuthorizeChargeWithSavedPaymentMethodOptions, AuthorizeChargeWithSavedPaymentMethodResponse, AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields, CalculateRefundOptions, CalculateRefundResponse, CalculateRefundResponseNonNullableFields, CaptureAuthorizedPaymentsOptions, CaptureAuthorizedPaymentsResponse, CaptureAuthorizedPaymentsResponseNonNullableFields, GetOrderRefundabilityResponse, GetOrderRefundabilityResponseNonNullableFields, RefundPaymentsOptions, RefundPaymentsResponse, RefundPaymentsResponseNonNullableFields, VoidAuthorizedPaymentsOptions, VoidAuthorizedPaymentsResponse, VoidAuthorizedPaymentsResponseNonNullableFields, authorizeChargeWithSavedPaymentMethod, calculateRefund, captureAuthorizedPayments, getOrderRefundability, refundPayments, voidAuthorizedPayments };
