import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { G as GetOrderRefundabilityResponse, a as GetOrderRefundabilityResponseNonNullableFields, C as CalculateRefundOptions, b as CalculateRefundResponse, c as CalculateRefundResponseNonNullableFields, R as RefundPaymentsOptions, d as RefundPaymentsResponse, e as RefundPaymentsResponseNonNullableFields, A as AuthorizeChargeWithSavedPaymentMethodOptions, f as AuthorizeChargeWithSavedPaymentMethodResponse, g as AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields, V as VoidAuthorizedPaymentsOptions, h as VoidAuthorizedPaymentsResponse, i as VoidAuthorizedPaymentsResponseNonNullableFields, j as CaptureAuthorizedPaymentsOptions, k as CaptureAuthorizedPaymentsResponse, l as CaptureAuthorizedPaymentsResponseNonNullableFields, m as GenerateReceiptsOptions, n as GenerateReceiptsResponse, o as GenerateReceiptsResponseNonNullableFields } from './ecom-v1-order-billing-order-billing.universal-CIazJpVg.js';
export { b0 as ActionEvent, u as ActionType, _ as AdditionalFeeRefund, W as AdditionalFeeRefundability, a1 as AggregatedRefundSummary, ac as ApplicationError, aF as AuthorizationActionFailureDetails, aE as AuthorizationCapture, r as AuthorizationCaptureStatus, aD as AuthorizationDetails, aG as AuthorizationVoid, s as AuthorizationVoidStatus, aO as AuthorizeChargeWithSavedPaymentMethodRequest, X as CalculateRefundRequest, a0 as CalculateRefundResponseStatusOneOf, a5 as CalculatedAdditionalFeeRefund, a3 as CalculatedLineItemRefund, a2 as CalculatedRefundItems, a7 as CalculatedRefundNotAvailableStatus, a4 as CalculatedRefundSummary, a6 as CalculatedShippingRefund, a8 as CalculationError, a9 as CalculationErrorItemOneOf, aS as CaptureAuthorizedPaymentsRequest, I as CreditCardPaymentMethodDetails, aP as DelayedCaptureSettings, aa as Details, ab as DetailsKindOneOf, aW as DomainEvent, aX as DomainEventBodyOneOf, aQ as Duration, D as DurationUnit, b1 as Empty, aY as EntityCreatedEvent, a$ as EntityDeletedEvent, a_ as EntityUpdatedEvent, aM as ExternalReceiptInfo, ae as FieldViolation, aU as GenerateReceiptsRequest, w as GetOrderRefundabilityRequest, aI as GiftCardPaymentDetails, Z as LineItemRefund, aw as LineItemRefundSummary, Q as LineItemRefundability, J as ManuallyRefundablePaymentStatus, M as ManuallyRefundableReason, aK as MembershipName, aJ as MembershipPaymentDetails, v as MembershipPaymentStatus, H as MembershipPaymentSummary, E as MonetaryPaymentSummary, K as NonRefundablePaymentStatus, N as NonRefundableReason, al as NotificationSideEffects, O as OrderBilling, ax as OrderTransactions, ay as Payment, aT as PaymentCapture, y as PaymentInfo, B as PaymentInfoPaymentMethodDetailsOneOf, z as PaymentInfoSummaryOneOf, aN as PaymentNotRefundableDetails, az as PaymentPaymentDetailsOneOf, aA as PaymentReceiptInfoOneOf, ah as PaymentRefund, P as PaymentRefundability, x as PaymentRefundabilityStatusOneOf, L as PaymentsSummary, F as Price, t as Reason, aV as ReceiptInfo, am as Refund, ap as RefundDetails, aq as RefundItem, Y as RefundItems, av as RefundItemsBreakdown, ag as RefundPaymentsRequest, ai as RefundSideEffects, q as RefundStatus, ao as RefundStatusInfo, an as RefundTransaction, aB as RegularPaymentDetails, aC as RegularPaymentDetailsPaymentMethodDetailsOneOf, aj as RestockItem, ak as RestockSideEffects, aZ as RestoreInfo, p as RuleType, S as ScheduledAction, $ as ShippingRefund, U as ShippingRefundability, af as SystemError, T as TransactionStatus, as as V1AdditionalFeeRefund, au as V1AggregatedRefundSummary, ar as V1LineItemRefund, aH as V1ScheduledAction, at as V1ShippingRefund, ad as ValidationError, aR as VoidAuthorizedPaymentsRequest, aL as WixReceiptInfo } from './ecom-v1-order-billing-order-billing.universal-CIazJpVg.js';

declare function getOrderRefundability$1(httpClient: HttpClient): GetOrderRefundabilitySignature;
interface GetOrderRefundabilitySignature {
    /**
     * Retrieves refund information about an order's payments, line items, shipping, and additional fees.
     *
     * The following information is returned:
     * - Whether a payment is refundable; previously refunded amounts; possible refund amounts for each payment.
     * - Refundable and previously refunded quantities for each line item, as well as shipping and additional fees.
     * @param - Order ID.
     */
    (orderId: string): Promise<GetOrderRefundabilityResponse & GetOrderRefundabilityResponseNonNullableFields>;
}
declare function calculateRefund$1(httpClient: HttpClient): CalculateRefundSignature;
interface CalculateRefundSignature {
    /**
     * Calculates refund amounts for a given list of an order's line items, shipping, and additional fees.
     * @param - Order ID.
     */
    (orderId: string, options?: CalculateRefundOptions | undefined): Promise<CalculateRefundResponse & CalculateRefundResponseNonNullableFields>;
}
declare function refundPayments$1(httpClient: HttpClient): RefundPaymentsSignature;
interface RefundPaymentsSignature {
    /**
     * Calls relevant payment providers and creates refund transactions for the requested payments.
     *
     * Refunds marked with `paymentRefunds.externalRefund = true` do not call payment providers and
     * only update the order's transactions records.
     * @param - Order ID.
     */
    (orderId: string, options?: RefundPaymentsOptions | undefined): Promise<RefundPaymentsResponse & RefundPaymentsResponseNonNullableFields>;
}
declare function authorizeChargeWithSavedPaymentMethod$1(httpClient: HttpClient): AuthorizeChargeWithSavedPaymentMethodSignature;
interface AuthorizeChargeWithSavedPaymentMethodSignature {
    /**
     * Authorizes a payment using an order's saved payment method.
     *
     * Use the `delayedCaptureSettings` field to specify whether the payment should also be captured/voided immediately or at a later time.
     * Alternatively, the payment can be manually captured or voided using the Capture Authorized Payments or Void Authorized Payments methods.
     * @param - Order ID.
     *
     * The order must have a saved payment method associated.
     * Pass the order ID to the List Transactions For Single Order method and search the response for a payment with `regularPaymentDetails.savedPaymentMethod: true`.
     * If no saved payment exists, the call will fail.
     */
    (orderId: string, options: AuthorizeChargeWithSavedPaymentMethodOptions): Promise<AuthorizeChargeWithSavedPaymentMethodResponse & AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields>;
}
declare function voidAuthorizedPayments$1(httpClient: HttpClient): VoidAuthorizedPaymentsSignature;
interface VoidAuthorizedPaymentsSignature {
    /**
     * Voids an order's authorized payments.
     * @param - Order ID.
     */
    (orderId: string, options: VoidAuthorizedPaymentsOptions): Promise<VoidAuthorizedPaymentsResponse & VoidAuthorizedPaymentsResponseNonNullableFields>;
}
declare function captureAuthorizedPayments$1(httpClient: HttpClient): CaptureAuthorizedPaymentsSignature;
interface CaptureAuthorizedPaymentsSignature {
    /**
     * Captures an order's authorized payments.
     * @param - Order ID.
     */
    (orderId: string, options: CaptureAuthorizedPaymentsOptions): Promise<CaptureAuthorizedPaymentsResponse & CaptureAuthorizedPaymentsResponseNonNullableFields>;
}
/** @internal */
declare function generateReceipts$1(httpClient: HttpClient): GenerateReceiptsSignature;
interface GenerateReceiptsSignature {
    /**
     * Generates receipts for an order's specified payments.
     * @param - Order ID.
     */
    (orderId: string, options: GenerateReceiptsOptions): Promise<GenerateReceiptsResponse & GenerateReceiptsResponseNonNullableFields>;
}

declare const getOrderRefundability: MaybeContext<BuildRESTFunction<typeof getOrderRefundability$1> & typeof getOrderRefundability$1>;
declare const calculateRefund: MaybeContext<BuildRESTFunction<typeof calculateRefund$1> & typeof calculateRefund$1>;
declare const refundPayments: MaybeContext<BuildRESTFunction<typeof refundPayments$1> & typeof refundPayments$1>;
declare const authorizeChargeWithSavedPaymentMethod: MaybeContext<BuildRESTFunction<typeof authorizeChargeWithSavedPaymentMethod$1> & typeof authorizeChargeWithSavedPaymentMethod$1>;
declare const voidAuthorizedPayments: MaybeContext<BuildRESTFunction<typeof voidAuthorizedPayments$1> & typeof voidAuthorizedPayments$1>;
declare const captureAuthorizedPayments: MaybeContext<BuildRESTFunction<typeof captureAuthorizedPayments$1> & typeof captureAuthorizedPayments$1>;
/** @internal */
declare const generateReceipts: MaybeContext<BuildRESTFunction<typeof generateReceipts$1> & typeof generateReceipts$1>;

export { AuthorizeChargeWithSavedPaymentMethodOptions, AuthorizeChargeWithSavedPaymentMethodResponse, AuthorizeChargeWithSavedPaymentMethodResponseNonNullableFields, CalculateRefundOptions, CalculateRefundResponse, CalculateRefundResponseNonNullableFields, CaptureAuthorizedPaymentsOptions, CaptureAuthorizedPaymentsResponse, CaptureAuthorizedPaymentsResponseNonNullableFields, GenerateReceiptsOptions, GenerateReceiptsResponse, GenerateReceiptsResponseNonNullableFields, GetOrderRefundabilityResponse, GetOrderRefundabilityResponseNonNullableFields, RefundPaymentsOptions, RefundPaymentsResponse, RefundPaymentsResponseNonNullableFields, VoidAuthorizedPaymentsOptions, VoidAuthorizedPaymentsResponse, VoidAuthorizedPaymentsResponseNonNullableFields, authorizeChargeWithSavedPaymentMethod, calculateRefund, captureAuthorizedPayments, generateReceipts, getOrderRefundability, refundPayments, voidAuthorizedPayments };
